@@ -25,6 +25,9 @@ class URL:
     def __str__(self):
         return self.url
 
+def model_to_data(model=None):
+    return tuple([i.data for i in model])
+
 class table_objects:
     def __init__(self, obj=None):
         self.obj = obj
@@ -32,21 +35,38 @@ class table_objects:
     def all(self):
         return self.obj.columns
     
-    def get(self, id=None):
+    def get(self, *args, **kwargs):
+        need = len(kwargs)
+        result = []
         for column in self.obj.columns:
-            if column.id == id:
-                return column
-        raise ValueError("目标栏不存在.")
+            transit = 0
+            for kwarg in kwargs:
+                if kwargs[kwarg] in column.data:
+                    transit += 1
+            if transit == need:
+                result.append(column)
+        if len(result) != 1:
+            raise ValueError("未找到或找到了多个匹配的数据，如果你试图筛选多数据，请参考‘filter’.")
+        return result
 
-    def create(self, datas=None):
-        if not isinstance(datas, list) and not isinstance(datas, tuple):
-            raise ValueError("参数'datas'必须为列表或元组.")
+    def create(self, *args, **kwargs):
         column = self.obj.repo.list_folder(path=self.obj.name, int=True)
         if len(column) == 0:
             column = 0
         else:
             column = max(column) + 1
         self.obj.repo.make_folder(path=URL(self.obj.name)/column)
+
+        datas = []
+        for name in self.obj.namespace:
+            if name == "id":
+                continue
+
+            if name in kwargs:
+                datas.append(kwargs[name])
+            else:
+                datas.append(None)
+
         for i in range(len(datas)):
             self.obj.repo.upload_file(
                 path = URL(self.obj.name) / column / i,
@@ -76,9 +96,6 @@ class table_objects:
             if transit == need:
                 result.append(column)
         return result
-        #for column in self.obj.columns:
-        #    if data == column.data:
-        #        return column
 
 class SqleeData:
     data = None
@@ -171,20 +188,20 @@ class SqleeColumn:
                     )
                 continue
             loads = self.repo.get_data(path=data["path"])
-            exec("self.%s = %s" % (self.namespace[int(data["name"])], loads))
+            self.__setattr__(self.namespace[int(data["name"]) + 1], loads)
             self.datas.append(
                 SqleeData(loads, url=data["url"],
                           namespace=self.namespace[int(data["name"])],
                           repo=self.repo)
                 )
         if len(datas) != len(self.namespace):
-            raise ValueError("数据错误: 数据与命名域不符合.")
+            print("数据错误: 数据与命名域不符合.")
         self.datas = tuple(self.datas)
         return self.datas
-        
-    def update(self, datas):
-        for data in datas:
-            self.datas[datas.index(data)].update(data)
+
+    def update(self, *args, **kwargs):
+        for kwarg in kwargs:
+            self.datas[self.namespace.index(kwarg)].update(data=kwargs[kwarg])
         self.sync()
         return self.datas
 
